#ifdef LOCAL
#include "../../testlib.h"
#else
#include "testlib.h"
#endif

#include <unordered_set>
#include <vector>

using namespace std;

void check(vector<unsigned int> const &values, vector<int> const &seq, unsigned int m, bool jury = false) {
    if (seq.size() == 0) {
        quitf(jury ? _fail : _wa, "No weights are put on scales");
    }

    unordered_multiset<long long> a(values.begin(), values.end());
    long long res = 0;
    for (int x : seq) {
        unsigned int t = x > 0 ? x : -x;
        if (a.count(t) == 0) {
            quitf(jury ? _fail : _wa, "Number %d in %s not found in input", x, jury ? "jury's answer" : "output");
        }
        a.erase(a.find(t));
        res += x;
    }
    if (res % m != 0) {
        quitf(jury ? _fail : _wa, "Sum %lld of %s is not divisible by %d",
              res, jury ? "jury's answer" : "output", m);
    }
}

int main(int argc, char *argv[]) {
    registerTestlibCmd(argc, argv);

    unsigned int n = inf.readInt(), m = inf.readInt();
    vector<unsigned int> values;
    for (unsigned int i = 0; i < n; i++) {
        values.push_back(inf.readInt());
    }

    int rans = ans.readInt(), r = ouf.readInt();
    if (r == -1 && rans == -1) {
        quitf(_ok, "Ok -1");
    } else {
        vector<int> jury, user;
        if (rans != -1) {
            unordered_set<unsigned int> idx;
            for (int i = 0; i < rans; i++) {
                int x = ans.readInt() - 1;
                if (x < 0 || x >= n) {
                    quitf(_fail, "Invalid range %d", x);
                } else if (idx.count(x) > 0) {
                    quitf(_fail, "Non-unique index %d", x);
                }
                idx.insert(x);
                jury.push_back(values[x]);
            }
            rans = ans.readInt();
            for (int i = 0; i < rans; i++) {
                int x = ans.readInt() - 1;
                if (x < 0 || x >= n) {
                    quitf(_fail, "Invalid range %d", x);
                } else if (idx.count(x) > 0) {
                    quitf(_fail, "Non-unique index %d", x);
                }
                idx.insert(x);
                jury.push_back(-values[x]);
            }
            check(values, jury, m, true);
        }
        if (r != -1) {
            unordered_set<unsigned int> idx;
            for (int i = 0; i < r; i++) {
                int x = ouf.readInt() - 1;
                if (x < 0 || x >= n) {
                    quitf(_wa, "Invalid range %d", x);
                } else if (idx.count(x) > 0) {
                    quitf(_wa, "Non-unique index %d", x);
                }
                idx.insert(x);
                user.push_back(values[x]);
            }
            r = ouf.readInt();
            for (int i = 0; i < r; i++) {
                int x = ouf.readInt() - 1;
                if (x < 0 || x >= n) {
                    quitf(_wa, "Invalid range %d", x);
                } else if (idx.count(x) > 0) {
                    quitf(_wa, "Non-unique index %d", x);
                }
                idx.insert(x);
                user.push_back(-values[x]);
            }
            check(values, user, m);
        }
        if (rans == -1 && r != -1) {
            quitf(_fail, "Contestant found the solution where jury has -1");
        } else if (rans != -1 && r == -1) {
            quitf(_wa, "Jury has a solution, while contestant has -1");
        } else {
            quitf(_ok, "All checks passed");
        }
    }

}
